#[non_exhaustive]pub struct CreateDataflowEndpointGroupInput {
pub endpoint_details: Option<Vec<EndpointDetails>>,
pub tags: Option<HashMap<String, String>>,
pub contact_pre_pass_duration_seconds: Option<i32>,
pub contact_post_pass_duration_seconds: Option<i32>,
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint_details: Option<Vec<EndpointDetails>>Endpoint details of each endpoint in the dataflow endpoint group. All dataflow endpoints within a single dataflow endpoint group must be of the same type. You cannot mix AWS Ground Station Agent endpoints with Dataflow endpoints in the same group. If your use case requires both types of endpoints, you must create separate dataflow endpoint groups for each type.
Tags of a dataflow endpoint group.
contact_pre_pass_duration_seconds: Option<i32>Amount of time, in seconds, before a contact starts that the Ground Station Dataflow Endpoint Group will be in a PREPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the PREPASS state.
contact_post_pass_duration_seconds: Option<i32>Amount of time, in seconds, after a contact ends that the Ground Station Dataflow Endpoint Group will be in a POSTPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the POSTPASS state.
Implementations
Sourceimpl CreateDataflowEndpointGroupInput
impl CreateDataflowEndpointGroupInput
Sourcepub fn endpoint_details(&self) -> &[EndpointDetails]
pub fn endpoint_details(&self) -> &[EndpointDetails]
Endpoint details of each endpoint in the dataflow endpoint group. All dataflow endpoints within a single dataflow endpoint group must be of the same type. You cannot mix AWS Ground Station Agent endpoints with Dataflow endpoints in the same group. If your use case requires both types of endpoints, you must create separate dataflow endpoint groups for each type.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .endpoint_details.is_none().
Tags of a dataflow endpoint group.
Sourcepub fn contact_pre_pass_duration_seconds(&self) -> Option<i32>
pub fn contact_pre_pass_duration_seconds(&self) -> Option<i32>
Amount of time, in seconds, before a contact starts that the Ground Station Dataflow Endpoint Group will be in a PREPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the PREPASS state.
Sourcepub fn contact_post_pass_duration_seconds(&self) -> Option<i32>
pub fn contact_post_pass_duration_seconds(&self) -> Option<i32>
Amount of time, in seconds, after a contact ends that the Ground Station Dataflow Endpoint Group will be in a POSTPASS state. A Ground Station Dataflow Endpoint Group State Change event will be emitted when the Dataflow Endpoint Group enters and exits the POSTPASS state.
Sourceimpl CreateDataflowEndpointGroupInput
impl CreateDataflowEndpointGroupInput
Sourcepub fn builder() -> CreateDataflowEndpointGroupInputBuilder
pub fn builder() -> CreateDataflowEndpointGroupInputBuilder
Creates a new builder-style object to manufacture CreateDataflowEndpointGroupInput.