#[non_exhaustive]pub struct SpectrumConfig {
pub center_frequency: Option<Frequency>,
pub bandwidth: Option<FrequencyBandwidth>,
pub polarization: Option<Polarization>,
}Expand description
Object that describes a spectral Config.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.center_frequency: Option<Frequency>Center frequency of a spectral Config. Valid values are between 2200 to 2300 MHz and 7750 to 8400 MHz for downlink and 2025 to 2120 MHz for uplink.
bandwidth: Option<FrequencyBandwidth>Bandwidth of a spectral Config. AWS Ground Station currently has the following bandwidth limitations:
-
For
AntennaDownlinkDemodDecodeconfig, valid values are between 125 kHz to 650 MHz. -
For
AntennaDownlinkconfigvalid values are between 10 kHz to 54 MHz. -
For
AntennaUplinkConfig, valid values are between 10 kHz to 54 MHz.
polarization: Option<Polarization>Polarization of a spectral Config. Capturing both "RIGHT_HAND" and "LEFT_HAND" polarization requires two separate configs.
Implementations
Sourceimpl SpectrumConfig
impl SpectrumConfig
Sourcepub fn center_frequency(&self) -> Option<&Frequency>
pub fn center_frequency(&self) -> Option<&Frequency>
Center frequency of a spectral Config. Valid values are between 2200 to 2300 MHz and 7750 to 8400 MHz for downlink and 2025 to 2120 MHz for uplink.
Sourcepub fn bandwidth(&self) -> Option<&FrequencyBandwidth>
pub fn bandwidth(&self) -> Option<&FrequencyBandwidth>
Bandwidth of a spectral Config. AWS Ground Station currently has the following bandwidth limitations:
-
For
AntennaDownlinkDemodDecodeconfig, valid values are between 125 kHz to 650 MHz. -
For
AntennaDownlinkconfigvalid values are between 10 kHz to 54 MHz. -
For
AntennaUplinkConfig, valid values are between 10 kHz to 54 MHz.
Sourcepub fn polarization(&self) -> Option<&Polarization>
pub fn polarization(&self) -> Option<&Polarization>
Polarization of a spectral Config. Capturing both "RIGHT_HAND" and "LEFT_HAND" polarization requires two separate configs.
Sourceimpl SpectrumConfig
impl SpectrumConfig
Sourcepub fn builder() -> SpectrumConfigBuilder
pub fn builder() -> SpectrumConfigBuilder
Creates a new builder-style object to manufacture SpectrumConfig.